@@ -22,6 +22,8 @@ OC.L10N.register(
     "An unknown error has occurred" : "Ett okänt fel uppstod",
     "File could not be uploaded" : "Filen kunde inte laddas upp",
     "Uploading …" : "Laddar upp ..",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "Laddar upp … ({currentNumber}/{total})",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} av {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "Uppladdning av det här objektet stöds inte",
     "Target folder does not exist any more" : "Målmapp existerar inte längre",
@@ -32,6 +34,7 @@ OC.L10N.register(
     "Move" : "Flytta",
     "Copy" : "Kopiera",
     "Choose target folder" : "Välj målmapp",
+    "Set reminder" : "Ställ in påminnelse",
     "Edit locally" : "Redigera lokalt",
     "Open" : "Öppna",
     "Delete file" : "Ta bort fil",
@@ -78,6 +81,7 @@ OC.L10N.register(
     "_including %n hidden_::_including %n hidden_" : ["inkluderar %n dold","inkluderar %n dolda"],
     "You do not have permission to upload or create files here" : "Du har inte behörighet att ladda upp eller skapa filer här",
     "_Uploading %n file_::_Uploading %n files_" : ["Laddar upp %n fil","Laddar upp %n filer"],
+    "New" : "Ny",
     "New file/folder menu" : "Ny fil/mapp -meny",
     "Select file range" : "Välj filintervall",
     "{used}%" : "{used}%",
@@ -107,8 +111,6 @@ OC.L10N.register(
     "Create new folder" : "Skapa ny mapp",
     "Upload file" : "Ladda upp fil",
     "Recent" : "Senaste",
-    "This file has the tag {tag}" : "Den här filen har taggen {tag}",
-    "This file has the tags {firstTags} and {lastTag}" : "Den här filen har taggarna {firstTags} och {lastTag}",
     "Not favorited" : "Inte favoriserade",
     "Remove from favorites" : "Ta bort från favoriter",
     "Add to favorites" : "Lägg till i favoriter",
@@ -154,7 +156,6 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "En fil har lagts till eller tagits bort från dina <strong>favoriter</strong>",
     "A file or folder has been <strong>changed</strong>" : "En ny fil eller mapp har blivit <strong>ändrad</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "En favorit-fil eller mapp har blivit <strong>ändrad</strong>",
-    "All files" : "Alla filer",
     "Upload (max. %s)" : "Ladda upp (högst %s)",
     "Accept" : "Acceptera",
     "Reject" : "Avvisa",
@@ -168,37 +169,46 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Ägaröverföringen av {path} från {user} är klar.",
     "in %s" : "om %s",
     "File Management" : "Filhantering",
+    "Current directory path" : "Aktuell katalogsökväg",
     "Reload current directory" : "Ladda om nuvarande mapp",
     "Go to the \"{dir}\" directory" : "Gå till \"{dir}\" mappen",
-    "Select the row for {displayName}" : "Välj raden för {displayName}",
-    "Rename file" : "Byt namn på fil",
-    "File name" : "Filnamn",
-    "A long time ago" : "För länge sedan",
-    "Download file {name}" : "Ladda ner filen {name}",
+    "Drag and drop files here to upload" : "Dra och släpp filer här för att ladda upp",
+    "Your have used your space quota and cannot upload files anymore" : "Du har använt din utrymmeskvot och kan inte längre ladda upp filer",
+    "You don’t have permission to upload or create files here" : "Du har inte tillåtelse att ladda upp eller skapa filer här",
+    "Upload successful" : "Uppladdningen lyckades",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\"-åtgärden har utförts",
     "\"{displayName}\" action failed" : "\"{displayName}\"-åtgärden misslyckades",
+    "Toggle selection for file \"{displayName}\"" : "Växla markering för filen \"{displayName}\"",
+    "Toggle selection for folder \"{displayName}\"" : "Växla markering för mappen \"{displayName}\"",
+    "Rename file" : "Byt namn på fil",
+    "File name" : "Filnamn",
+    "Folder name" : "Mappnamn",
+    "This node is unavailable" : "Den här noden är inte tillgänglig",
+    "Download file {name}" : "Ladda ner filen {name}",
     "\"{name}\" is not an allowed filetype." : "\"{name}\" är inte en tillåten filtyp.",
     "{newName} already exists." : "{newName} finns redan.",
+    "\"{char}\" is not allowed inside a file name." : "\"{char}\" är inte tillåtet i ett filnamn.",
     "Name cannot be empty" : "Namn kan inte vara tom",
     "Another entry with the same name already exists" : "En annan post med samma namn finns redan",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Bytte namn på \"{oldName}\" till \"{newName}\"",
     "Could not rename \"{oldName}\", it does not exist any more" : "Kunde inte byta namn på \"{oldName}\", den finns inte längre",
-    "The name \"{newName}\"\" is already used in the folder \"{dir}\". Please choose a different name." : "Namnet \"{newName}\"\" används redan i mappen \"{dir}\". Välj ett annat namn.",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Namnet \"{newName}\" används redan i mappen \"{dir}\". Välj ett annat namn.",
     "Could not rename \"{oldName}\"" : "Kunde inte byta namn på \"{oldName}\"",
+    "Could not copy {file}. {message}" : "Kunde inte kopiera {file}. {message}",
+    "Could not move {file}. {message}" : "Kunde inte flytta {file}. {message}",
     "Total rows summary" : "Sammanfattning antal rader",
-    "Select all" : "Välj allt",
-    "Unselect all" : "Avmarkera alla",
+    "Toggle selection for all files and folders" : "Växla markering för alla filer och mappar",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" misslyckades med vissa element",
     "\"{displayName}\" batch action executed successfully" : "Batchåtgärden \"{displayName}\" har utförts",
-    "ascending" : "stigande",
-    "descending" : "fallande",
-    "Sort list by {column} ({direction})" : "Sortera listan efter {column} ({direction})",
     "List of files and folders." : "Lista över filer och mappar.",
+    "Column headers with buttons are sortable." : "Kolumnrubriker med knappar är sorterbara.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Denna lista är inte helt återgiven av prestandaskäl. Filerna kommer att renderas när du navigerar genom listan.",
+    "File not found" : "Filen kunde inte hittas",
     "Storage informations" : "Lagringsinformation",
     "{usedQuotaByte} used" : "{usedQuotaByte} använt",
     "{relative}% used" : "{relative}% använt",
     "Could not refresh storage stats" : "Det gick inte att uppdatera lagringsstatistiken",
+    "Your storage is full, files can not be updated or synced anymore!" : "Ditt lagringsutrymme är fullt, filer kan inte längre uppdateras eller synkroniseras!",
     "Transfer ownership of a file or folder" : "Överför ägarskap av en fil eller mapp",
     "Choose file or folder to transfer" : "Välj fil eller mapp att överföra",
     "Change" : "Ändra",
@@ -211,20 +221,34 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Förfrågan om ägaröverföring skickad",
     "Cannot transfer ownership of a file or folder you do not own" : "Det går inte att överföra äganderätten till en fil eller mapp som du inte äger",
     "Select file or folder to link to" : "Välj fil eller mapp att länka till",
+    "Choose file" : "Välj fil",
+    "Choose {file}" : "Välj {file}",
+    "Add" : "Lägg till",
     "Loading current folder" : "Laddar aktuell mapp",
     "No files in here" : "Inga filer kunde hittas",
     "Upload some content or sync with your devices!" : "Ladda upp innehåll eller synkronisera med dina enheter!",
     "Go to the previous folder" : "Gå till föregående mapp",
     "Go back" : "Gå tillbaks",
+    "Share" : "Dela",
+    "Shared by link" : "Delad via länk",
+    "Shared" : "Delad",
+    "Switch to list view" : "Växla till listvy",
+    "Switch to grid view" : "Växla till rutnätsvy",
+    "Error during upload: {message}" : "Fel vid uppladdning: {message}",
+    "Error during upload, status code {status}" : "Fel vid uppladdning, statuskod {status}",
+    "Unknown error during upload" : "Okänt fel under uppladdning",
     "Open the files app settings" : "Öppna filappens inställningar",
     "Files settings" : "Filinställningar",
     "File cannot be accessed" : "Det går inte att komma åt filen",
-    "You might not have have permissions to view it, ask the sender to share it" : "Du kanske inte har behörighet att se den, be avsändaren att dela den",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Filen kunde inte hittas eller så har du inte behörighet att visa den. Be avsändaren att dela den.",
     "Sort favorites first" : "Sortera favoriter först",
+    "Sort folders before files" : "Sortera mappar före filer",
     "Show hidden files" : "Visa dolda filer",
     "Crop image previews" : "Beskär förhandsgranskningar för bilder",
+    "Enable the grid view" : "Aktivera rutnätsvy",
     "Additional settings" : "Övriga inställningar",
     "WebDAV" : "WebDAV",
+    "WebDAV URL" : "WebDAV URL",
     "Copy to clipboard" : "Kopiera till urklipp",
     "Use this address to access your Files via WebDAV" : "Använd denna adress för att komma åt dina filer med WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Om du har aktiverat 2FA måste du skapa och använda ett nytt applösenord genom att klicka här.",
@@ -239,44 +263,71 @@ OC.L10N.register(
     "Blank" : "Tom",
     "Unable to create new file from template" : "Kunde inte skapa fil från mall",
     "Delete permanently" : "Ta bort permanent",
+    "Destination is not a folder" : "Destinationen är inte en mapp",
+    "This file/folder is already in that directory" : "Den här filen/mappen finns redan i den katalogen",
+    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Du kan inte flytta en fil/mapp till sig själv eller till en undermapp till sig själv",
+    "(copy)" : "(kopia)",
+    "(copy %n)" : "(kopia %n)",
+    "A file or folder with that name already exists in this folder" : "En fil eller mapp med det namnet finns redan i den här mappen",
+    "The files is locked" : "Filerna är låsta",
+    "The file does not exist anymore" : "Filen finns inte längre",
+    "Choose destination" : "Välj destination",
+    "Copy to {target}" : "Kopiera till {target}",
+    "Move to {target}" : "Flytta till {target}",
+    "Cancelled move or copy operation" : "Flytta eller kopiera avbröts",
+    "Move or copy operation failed" : "Flytta eller kopiera misslyckades",
     "Open folder {displayName}" : "Öppna mappen {displayName}",
     "Open in Files" : "Öppna i Filer",
     "Open details" : "Öppna detaljer",
-    "Set up templates folder" : "Skapa en mapp för mallar",
-    "Templates" : "Mallar",
     "Create new templates folder" : "Skapa ny mallmapp",
+    "Templates" : "Mallar",
     "Unable to initialize the templates directory" : "Kunde inte initialisera mall-mappen",
+    "Created new folder \"{name}\"" : "Skapat ny mapp \"{name}\"",
+    "One of the dropped files could not be processed" : "En av de släppta filerna kunde inte bearbetas",
+    "Uploading \"{filename}\" failed" : "Uppladdning av \"{filename}\" misslyckades",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} mapp","{folderCount} mappar"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} fil","{fileCount} filer"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 fil och {folderCount} mapp","1 fil och {folderCount} mappar"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} fil och 1 mapp","{fileCount} filer och 1 mapp"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} filer och {folderCount} mappar",
     "List of favorites files and folders." : "Lista över favoritfiler och mappar.",
     "No favorites yet" : "Inga favoriter ännu",
     "Files and folders you mark as favorite will show up here" : "Filer och mappar markerade som favoriter kommer att visas här",
+    "All files" : "Alla filer",
+    "List of your files and folders." : "Lista över dina filer och mappar.",
     "List of recently modified files and folders." : "Lista över nyligen ändrade filer och mappar.",
     "No recently modified files" : "Inga nyligen ändrade filer",
     "Files and folders you recently modified will show up here." : "Filer och mappar som du nyligen ändrat kommer att visas här.",
-    "Toggle %1$s sublist" : "Växla %1$s sublista",
-    "Toggle grid view" : "Växla rutnätsvy",
     "No entries found in this folder" : "Inget innehåll hittades i denna mapp",
+    "Select all" : "Välj allt",
     "Upload too large" : "För stor uppladdning",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filerna du försöker ladda upp överstiger den maximala storleken för filöverföringar på servern.",
     "Text file" : "Textfil",
     "New text file.txt" : "Ny textfil.txt",
-    "Storage invalid" : "Lagring ogiltig",
     "You can only favorite a single file or folder at a time" : "Du kan bara favoritmarkera en fil eller mapp åt gången",
-    "Unlimited" : "Obegränsad",
     "Search users" : "Sök användare",
+    "You might not have have permissions to view it, ask the sender to share it" : "Du kanske inte har behörighet att se den, be avsändaren att dela den",
     "Cancel" : "Avbryt",
-    "%s used" : "%s använt",
-    "%s%%" : "%s%%",
-    "%1$s of %2$s used" : "%1$s av %2$s använt",
+    "Set up templates folder" : "Skapa en mapp för mallar",
+    "Toggle %1$s sublist" : "Växla %1$s sublista",
+    "Toggle grid view" : "Växla rutnätsvy",
     "Deleted files" : "Borttagna filer",
     "Shares" : "Delningar",
     "Shared with others" : "Delas med andra",
     "Shared with you" : "Delas med mig",
-    "Shared by link" : "Delad via länk",
     "Deleted shares" : "Borttagna delningar",
     "Pending shares" : "Väntande delningar",
+    "This file has the tag {tag}" : "Den här filen har taggen {tag}",
+    "This file has the tags {firstTags} and {lastTag}" : "Den här filen har taggarna {firstTags} och {lastTag}",
+    "Select the row for {displayName}" : "Välj raden för {displayName}",
     "Open folder {name}" : "Öppna mappen {name}",
+    "Unselect all" : "Avmarkera alla",
+    "ascending" : "stigande",
+    "descending" : "fallande",
+    "Sort list by {column} ({direction})" : "Sortera listan efter {column} ({direction})",
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Denna lista är inte helt återgiven av prestandaskäl. Filerna kommer att renderas när du navigerar genom listan.",
     "Search for an account" : "Sök efter ett konto",
+    "Choose" : "Välj",
     "No files or folders have been deleted yet" : "Inga filer eller mappar har tagits bort än"
 },
 "nplurals=2; plural=(n != 1);");
